﻿$LogPath = $(Join-Path $env:ProgramData 'Druide')
$ScriptLog = $(Join-Path $LogPath 'logAssistantTelechargement.txt')

enum MsiExecErrorCode {
    ERROR_SUCCESS = 0
    ERROR_SUCCESS_REBOOT_INITIATED = 1641
    ERROR_SUCCESS_REBOOT_REQUIRED = 3010
    ERROR_UNKNOWN_PRODUCT = 1605
    ERROR_INSTALL_ALREADY_RUNNING = 1618
}

$SuccessCodes = @(
    [MsiExecErrorCode]::ERROR_SUCCESS,
    [MsiExecErrorCode]::ERROR_SUCCESS_REBOOT_REQUIRED,
    [MsiExecErrorCode]::ERROR_UNKNOWN_PRODUCT # Le paquet est déjà désinstallé.
)

$ATVersions = [ordered]@{
    'v6.71.0'  = '{93154A3C-9BB7-49D7-A571-4EB6373FA602}'
    'v6.70.0'  = '{93154A3C-9BB7-49D7-A571-4EB6373FA601}'
    'v6.1.0'   = '{93154A3C-9BB7-49D7-A571-4EB6373FA600}'
    'v5.65.15' = '{92154A3C-9BB7-49D7-A571-4EB6373FA601}'
    'v5.65.13' = '{92154A3C-9BB7-49D7-A571-4EB6373FA5AD}'
    'v5.65.12' = '{FCA2FF70-4D86-42CE-AD8C-A54C706FE41C}'
}

New-Item -ItemType Directory -Force -Path $LogPath

Add-Content -Path $ScriptLog -Value "Désinstallation de l'Assistant de téléchargement"

$Installer = New-Object -ComObject WindowsInstaller.Installer

$ShouldRestart = $false
foreach ($Version in $ATVersions.GetEnumerator()) {
    $InstalledProducts = $Installer.ProductsEx($Version.Value, '', 7)
    if ( $InstalledProducts.Count() -gt 0 ) {
        $Arguments = @(
            '/qn',
            '/x',
            "$($Version.Value)",
            'MSIRESTARTMANAGERCONTROL=DisableShutdown',
            'REBOOT=ReallySuppress',
            '/l*v',
            """$LogPath\logDesAt$($Version.Key).txt"""
        )
        Add-Content -Path $ScriptLog -Value "Désinstallation de l'Assistant de téléchargement $($Version.Key) $Arguments"
        $Process = Start-Process 'msiexec.exe' -ArgumentList $Arguments -Wait -NoNewWindow -PassThru
        if ($Process.ExitCode -notin $SuccessCodes) {
            exit $Process.ExitCode
        } elseif ($Process.ExitCode -eq [MsiExecErrorCode]::ERROR_SUCCESS_REBOOT_REQUIRED) {
            $ShouldRestart = $true
        }
    } else {
        Add-Content -Path $ScriptLog -Value "L'Assistant de téléchargement $($Version.Key) est déjà désinstallé."
    }

}

Add-Content -Path $ScriptLog -Value "Désinstallation de l'Assistant de téléchargement terminé."

if ($ShouldRestart) {
    exit [int][MsiExecErrorCode]::ERROR_SUCCESS_REBOOT_REQUIRED
} else {
    exit [int][MsiExecErrorCode]::ERROR_SUCCESS
}