﻿$LogPath = $(Join-Path $env:ProgramData 'Druide')
$ScriptLog = $(Join-Path $LogPath 'logPrecedentsAntidote.txt')

enum MsiExecErrorCode {
    ERROR_SUCCESS = 0
    ERROR_SUCCESS_REBOOT_INITIATED = 1641
    ERROR_SUCCESS_REBOOT_REQUIRED = 3010
    ERROR_UNKNOWN_PRODUCT = 1605
    ERROR_INSTALL_ALREADY_RUNNING = 1618
}

$SuccessCodes = @(
    [MsiExecErrorCode]::ERROR_SUCCESS,
    [MsiExecErrorCode]::ERROR_SUCCESS_REBOOT_REQUIRED,
    [MsiExecErrorCode]::ERROR_UNKNOWN_PRODUCT # Le paquet est déjà désinstallé.
)

$AntidoteVersions = [ordered]@{
    'RX'                   = '{A474EA56-5DBD-4181-8230-806A4762EA7F}'
    'HD'                   = '{56CDB4FE-895F-4E0D-8BB4-9A8D4310898D}'
    '8'                    = '{09AAAB09-6DBA-4DD9-9865-54597D3FBCA8}'
    '9'                    = '{BFA17B4C-70D3-480F-8476-76197F614AB6}'
    '9 - Module Français'  = '{BFA17B4C-70D3-480F-8476-76197F614AB7}'
    '9 - English Module'   = '{BFA17B4C-70D3-480F-8476-76197F614AB8}'
    '10'                   = '{134E0741-C569-4E8C-A7FC-7F95B14CAAB1}'
    '10 - Module Français' = '{134E0741-C569-4E8C-A7FC-7F95B14CAAB2}'
    '10 - English Module'  = '{134E0741-C569-4E8C-A7FC-7F95B14CAAB3}'
    '10 - Connectix'       = '{134E0741-C569-4E8C-A7FC-7F95B14CAAB4}'
}

$ForceStopRequiredVersions = @(
    'RX',
    'HD',
    '8',
    '9'
)

New-Item -ItemType Directory -Force -Path $LogPath

Add-Content -Path $ScriptLog -Value "Désintallation des éditions précédentes d'Antidote"

$Installer = New-Object -ComObject WindowsInstaller.Installer

$ShouldRestart = $false
foreach ($Version in $AntidoteVersions.GetEnumerator()) {
    $InstalledProducts = $Installer.ProductsEx($Version.Value, '', 7)
    if ( $InstalledProducts.Count() -gt 0 ) {
        $Arguments = @(
            '/qn',
            '/x',
            "$($Version.Value)",
            'MSIRESTARTMANAGERCONTROL=DisableShutdown',
            'REBOOT=ReallySuppress',
            '/l*v',
            """$LogPath\logDesAntidote$($Version.Key -replace ' (- ){0,1}', '_').txt"""
        )
        Add-Content -Path $ScriptLog -Value "Désintallation d'Antidote $($Version.Key) $Arguments"
        if ($Version.Key -in $ForceStopRequiredVersions) {
            Add-Content -Path $ScriptLog -Value "Arrêt de Antidote.exe pour Antidote $($Version.Key)"
            Get-Process -Name Antidote | Stop-Process -Force
        }
        $Process = Start-Process 'msiexec.exe' -ArgumentList $Arguments -Wait -NoNewWindow -PassThru
        if ($Process.ExitCode -notin $SuccessCodes) {
            exit $Process.ExitCode
        } else {
            $ShouldRestart = $true
        }
    } else {
        Add-Content -Path $ScriptLog -Value "Antidote $($Version.Key) est déjà désintallé."
    }

}

Add-Content -Path $ScriptLog -Value "Désintallation des éditions précédentes d'Antidote terminé"

if ($ShouldRestart) {
    exit [int][MsiExecErrorCode]::ERROR_SUCCESS_REBOOT_REQUIRED
} else {
    exit [int][MsiExecErrorCode]::ERROR_SUCCESS
}