﻿[CmdletBinding(SupportsShouldProcess)]
param ()

$LogPath = $(Join-Path $env:ProgramData 'Druide')
$ScriptLog = $(Join-Path $LogPath 'logAntidote11.txt')

$Products = @(
    [PSCustomObject]@{
        Name          = 'Antidote 11'
        Code          = '{2643823D-D15F-4046-8388-401756A5C921}'
        UninstallLog  = 'logDesAntidote11.txt'
        AlwaysRestart = $false
    },
    [PSCustomObject]@{
        Name          = 'Antidote 11 - Module Français'
        Code          = '{2643823D-D15F-4046-8388-401756A5C922}'
        UninstallLog  = 'logDesAntidote11_Module_Français.txt'
        AlwaysRestart = $false
    },
    [PSCustomObject]@{
        Name          = 'Antidote 11 - English Module'
        Code          = '{2643823D-D15F-4046-8388-401756A5C923}'
        UninstallLog  = 'logDesAntidote11_English_Module.txt'
        AlwaysRestart = $false
    },
    [PSCustomObject]@{
        Name          = 'Antidote - Connectix 11'
        Code          = '{2643823D-D15F-4046-8388-401756A5C924}'
        UninstallLog  = 'logDesAntidote11_Connectix.txt'
        AlwaysRestart = $true
    }
)

enum MsiExecErrorCode {
    ERROR_SUCCESS = 0
    ERROR_SUCCESS_REBOOT_INITIATED = 1641
    ERROR_SUCCESS_REBOOT_REQUIRED = 3010
    ERROR_UNKNOWN_PRODUCT = 1605
    ERROR_INSTALL_ALREADY_RUNNING = 1618
}

$SuccessCodes = @(
    [MsiExecErrorCode]::ERROR_SUCCESS,
    [MsiExecErrorCode]::ERROR_SUCCESS_REBOOT_REQUIRED,
    [MsiExecErrorCode]::ERROR_UNKNOWN_PRODUCT # Le paquet est déjà désinstallé.
)

$ShouldRestart = $false

New-Item -ItemType Directory -Force -Path $LogPath

Add-Content -Path $ScriptLog -Value "Désinstallation d'Antidote 11"

foreach ($Product in $Products) {
    $UninstallArguments = @(
        '/qn',
        '/x',
        $Product.Code,
        'MSIRESTARTMANAGERCONTROL=DisableShutdown',
        'REBOOT=ReallySuppress',
        '/l*v',
        """$LogPath\$($Product.UninstallLog)"""
    )
    Add-Content -Path $ScriptLog -Value "Désinstallation de $($Product.Name) : $UninstallArguments"
    if ($PSCmdlet.ShouldProcess("$($Product.Name) : $UninstallArguments", 'Désinstallation')) {
        $Process = Start-Process 'msiexec.exe' -ArgumentList $UninstallArguments -Wait -NoNewWindow -PassThru
        if ($Process.ExitCode -notin $SuccessCodes) {
            exit $Process.ExitCode
        } elseif ($Process.ExitCode -eq [MsiExecErrorCode]::ERROR_SUCCESS_REBOOT_REQUIRED -or
                  ($Product.AlwaysRestart -and ($Process.ExitCode -ne [MsiExecErrorCode]::ERROR_UNKNOWN_PRODUCT))) {
            $ShouldRestart = $true
        }
    }
}

Add-Content -Path $ScriptLog -Value "Désinstallation d'Antidote 11 terminé"

if ($ShouldRestart) {
    exit [int][MsiExecErrorCode]::ERROR_SUCCESS_REBOOT_REQUIRED
} else {
    exit [int][MsiExecErrorCode]::ERROR_SUCCESS
}